@@ -3,9 +3,9 @@
 // @namespace      None
 // @description    Sets embed's and object's wmode parameter to 'direct' to enable hw acceleration
 // @include        *
+// @grant          none
 // ==/UserScript==
 
-
 (function ()
 {
 	nodeInserted();
@@ -24,7 +24,7 @@ function nodeInserted()
 			{
 				if (param.getAttribute("name") == "wmode")
 				{
-				param.setAttribute("value", "direct");
+					param.setAttribute("value", "direct");
 					skip = true;
 					break;
 				}
@@ -37,17 +37,12 @@ function nodeInserted()
 		}
 	}
 
-	if (typeof document.embeds != 'undefined')
-	{
-		for (var ems = document.embeds, i = 0, em; em = ems[i]; i++)
-		{
-			if ((em.getAttribute('wmode') && em.getAttribute('wmode') == 'direct')) continue;
-			em.setAttribute('wmode', 'direct');
-			var nx = em.nextSibling, pn = em.parentNode;
-			pn.removeChild(em);
-			document.removeEventListener('DOMNodeInserted', nodeInserted, false);
-			pn.insertBefore(em, nx);
-			document.addEventListener("DOMNodeInserted", nodeInserted, false);
-		}
+	for (var embeds = document.getElementsByTagName("embed"), i = 0, embed; embed = embeds[i]; i++) {
+		if (embed.type != 'application/x-shockwave-flash') continue;
+		if ((embed.getAttribute('wmode') && embed.getAttribute('wmode') == 'direct')) continue;
+		embed.setAttribute('wmode', 'direct');
+		var html = embed.outerHTML;
+		embed.insertAdjacentHTML('beforeBegin', embed.outerHTML);
+		embed.parentNode.removeChild(embed);
 	}
 }
