@@ -3,7 +3,7 @@
 // initializing/finalizing number of times a row with some drawing between.
 // This test is to reveal thread-safety failure inside VDPAU library.
 //
-// Initialization function executed once, but then 30 threads try to do the same work
+// Initialization function executed once, but then THREAD_COUNT threads try to do the same work
 // with rendering simultaneously.
 
 #include "tests-common.h"
@@ -32,9 +32,12 @@ void *thread_1_func(void *p)
     ASSERT_OK(vdpBitmapSurfaceCreate(device, VDP_RGBA_FORMAT_B8G8R8A8, 300, 150, 1, &bmp_surface));
 
     uint32_t buf[300*150];
+    for (uint32_t k = 0; k < 300*150; k ++)
+        buf[k] = 0xff000000u + (k & 0xffffffu);
+
     const void * const source_data[] = { buf };
     uint32_t source_pitches[] = { 4 * 300 };
-    for (int k = 0; k < 300*150; k ++) { buf[k] = 0xff000000 + (k & 0xffffff); }
+
     ASSERT_OK(vdpBitmapSurfacePutBitsNative(bmp_surface, source_data, source_pitches, NULL));
     VdpTime vdpTime = 0;
     ASSERT_OK(vdpPresentationQueueBlockUntilSurfaceIdle(pq, out_surface, &vdpTime));
@@ -67,11 +70,10 @@ void *thread_1_func(void *p)
 
 int main(void)
 {
-    Display *dpy = get_dpy();
     window = get_wnd();
     pthread_t pt[THREAD_COUNT];
 
-    ASSERT_OK(vdpDeviceCreateX11(dpy, 0, &device, NULL));
+    device = create_vdp_device();
 
     for (int k = 0; k < THREAD_COUNT; k ++)
         pthread_create(&pt[k], NULL, thread_1_func, NULL);
